<?php

namespace Drupal\urban_airship_web_push_notifications\Form\Rule;

use Drupal\Core\Url;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\urban_airship_web_push_notifications\Helper\NotificationRules;

/**
 * Delete Notifications Rule.
 */
class NotificationsDeleteForm extends ConfirmFormBase {

  protected $notification;

  /**
   * {@inheritdoc}.
   */
  public function getFormId() {
    return 'uawn_notification_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $bundle_label = \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->load($this->notification->getBundle())
      ->label();
    return t('You are about to delete <em>@bundle (@entity_type)</em> notification rule?', [
      '@entity_type' => $this->notification->getEntityType(),
      '@bundle'      => $bundle_label,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('urban_airship_web_push_notifications.notification_rules');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('Are you sure you would like to continue? This operation cannot be undone.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete Rule');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return $this->t('Cancel');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $rule_id = NULL) {
    $this->notification = (new NotificationRules())->setId($rule_id)->load();
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    drupal_set_message($this->t('<em>@bundle (@entity_type)</em> notification rule successfully deleted.', [
      '@entity_type' => $this->notification->getEntityType(),
      '@bundle'      => $this->notification->getBundle(),
    ]));
    $this->notification->delete();
    $form_state->setRedirect('urban_airship_web_push_notifications.notification_rules');
  }

}
