<?php

namespace Drupal\urban_airship_web_push_notifications\Form\Rule;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\urban_airship_web_push_notifications\Helper\NotificationRules;

/**
 * New Notifications Rule.
 */
class NotificationsNewForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uawn_notification_new_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $entity_type_manager = \Drupal::entityTypeManager();
    $bundle_info = \Drupal::service("entity_type.bundle.info")->getAllBundleInfo();

    $supported_entity_types = ['node'];
    $bundles = [];

    foreach ($supported_entity_types as $entity_type) {
      if (!empty($bundle_info[$entity_type])) {
        foreach ($bundle_info[$entity_type] as $bundle => $info) {
          $bundles[$bundle . '::' . $entity_type] = !empty($info['label']) ? $info['label'] : '';
        }
      }
    } 

    $form['bundle'] = [
      '#type'        => 'select',
      '#options'     => $bundles,
      '#title'       => $this->t('Node Type'),
      '#description' => $this->t('Node Type to tirgger notification'),
    ];

    $form['notification_mode'] = [
      '#type'          => 'radios',
      '#title'         => $this->t('Notification Mode'),
      '#description'   => $this->t('<ul style="margin-left: 0px; padding-left: 20px;"><li><b>Auto</b> - Notifications will be pushed to Urban Airship service via Push API depending on the setting in <b>Trigger Notification On</b> field.</li><li><b>Manual</b> - Choosing this option will provide additional checkbox (<b>Do not send notification by default</b>) that would determine whether notification checkbox on an individual content level should be checked (ON) by default or not (OFF).</li></ul>'),
      '#default_value' => UAWN_MODE_AUTO,
      '#options'       => [
        UAWN_MODE_AUTO   => $this->t('Auto'),
        UAWN_MODE_MANUAL => $this->t('Manual'),
      ],
    ];
    $form['manual_mode_default'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Send notifications by default'),
      '#default_value' => UAWN_MODE_MANUAL_DEFAULT_OFF,
      '#description'   => $this->t('This option determines whether notification checkbox on an individual content level should be checked (ON) by default or not (OFF).'),
      '#options'       => [
        UAWN_MODE_MANUAL_DEFAULT_ON  => $this->t('Notification option is ON'),
        UAWN_MODE_MANUAL_DEFAULT_OFF => $this->t('Notification option is OFF'),
      ],
      '#states' => [
        'visible' => [
          ':input[name="notification_mode"]' => ['value' => UAWN_MODE_MANUAL],
        ],
      ],
    ];
    $form['trigger_new'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('New Content'),
      '#description'   => $this->t('Event when notification should be sent to Urban Airship.'),
      '#default_value' => TRUE,
    ];
    $form['trigger_new_template'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Notification message when New Content created'),
      '#states'        => [
        'visible' => [
          ':input[name="trigger_new"]' => ['checked' => TRUE],
        ],
      ],
    ];

    if (\Drupal::moduleHandler()->moduleExists('token')) {
      $form['token_tree'] = [
        '#theme'       => 'token_tree_link',
        '#token_types' => ['node'],
      ];
    }

    $form['trigger_update'] = [
      '#type'        => 'checkbox',
      '#title'       => $this->t('Update Content'),
      '#description' => $this->t('Event when notification should be sent to Urban Airship.'),
    ];
    $form['trigger_update_template'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Notification message when Content updated'),
      '#states'        => [
        'visible' => [
          ':input[name="trigger_update"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['trigger_delete'] = [
      '#type'        => 'checkbox',
      '#title'       => $this->t('Delete Content'),
      '#description' => $this->t('Event when notification should be sent to Urban Airship.'),
    ];
    $form['trigger_delete_template'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Notification message when Content deleted'),
      '#states'        => [
        'visible' => [
          ':input[name="trigger_delete"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type'        => 'submit',
      '#value'       => $this->t('Create Rule'),
      '#button_type' => 'primary',
    ];
    $form['actions']['cancel'] = [
      '#type'  => 'link',
      '#title' => $this->t('Cancel'),
      '#url'   => Url::fromRoute('urban_airship_web_push_notifications.notification_rules'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->cleanValues();
    $info = explode('::', $form_state->getValue('bundle'));
    (new NotificationRules())
      ->setBundle($info[0])
      ->setEntityType($info[1])
      ->setNotificationMode($form_state->getValue('notification_mode'))
      ->setManualModeDefault($form_state->getValue('manual_mode_default'))
      ->setTriggerNew($form_state->getValue('trigger_new'))
      ->setTriggerNewTemplate($form_state->getValue('trigger_new_template'))
      ->setTriggerUpdate($form_state->getValue('trigger_update'))
      ->setTriggerUpdateTemplate($form_state->getValue('trigger_update_template'))
      ->setTriggerDelete($form_state->getValue('trigger_delete'))
      ->setTriggerDeleteTemplate($form_state->getValue('trigger_delete_template'))
      ->save();
    drupal_set_message($this->t('New Notification Rule successfully created'));
    $form_state->setRedirect('urban_airship_web_push_notifications.notification_rules');
  }

}
